@@ -42,12 +42,19 @@ class ArangoPipeAdmin:
         self.config = None
         self.cfg = None
         self.mscp = ManagedServiceConnParam()
+        self.use_supp_config_to_reconnect = False
 
         if reuse_connection:
-            info_msg = "since connection reuse is indicated, " + \
-                        "conn information is ignored if provided."
-            self.config = self.create_config()
-            self.cfg = self.config.get_cfg()
+            info_msg = "If a config is provided, it will be used for setting up the connection"
+            if config is None:
+                self.config = self.create_config()
+                self.cfg = self.config.get_cfg()
+                self.use_supp_config_to_reconnect = False
+            else:
+                self.config = config
+                self.cfg = config.cfg
+                self.use_supp_config_to_reconnect = True
+
             logger.info(info_msg)
         else:
 
@@ -212,18 +219,26 @@ class ArangoPipeAdmin:
             self.cfg['arangodb'][self.mscp.DB_CONN_PROTOCOL] = db_conn_protocol
 
         else:
-            disk_cfg = ArangoPipeConfig()
-            pcfg = disk_cfg.get_cfg()  # persisted config values
-            ms_dbName = pcfg['arangodb'][self.mscp.DB_NAME]
-            ms_user_name = pcfg['arangodb'][self.mscp.DB_USER_NAME]
-            ms_password = pcfg['arangodb'][self.mscp.DB_PASSWORD]
-            self.config = disk_cfg
-            self.cfg = disk_cfg.cfg
+            if self.use_supp_config_to_reconnect:
+                ms_dbName = self.cfg['arangodb'][self.mscp.DB_NAME]
+                ms_user_name = self.cfg['arangodb'][self.mscp.DB_USER_NAME]
+                ms_password = self.cfg['arangodb'][self.mscp.DB_PASSWORD]
+
+            else:
+                disk_cfg = ArangoPipeConfig()
+                pcfg = disk_cfg.get_cfg()  # persisted config values
+                ms_dbName = pcfg['arangodb'][self.mscp.DB_NAME]
+                ms_user_name = pcfg['arangodb'][self.mscp.DB_USER_NAME]
+                ms_password = pcfg['arangodb'][self.mscp.DB_PASSWORD]
+                self.config = disk_cfg
+                self.cfg = disk_cfg.cfg
         # Connect to arangopipe database as administrative user.
         #This returns an API wrapper for "test" database.
+        print("Host Connection: " + str(host_connection))
         client = ArangoClient(hosts= host_connection,\
                               http_client=CustomHTTPClient(username = ms_user_name,\
                                                            password = ms_password))
+
         db = client.db(ms_dbName, ms_user_name, ms_password)
         self.db = db
 
